@@ -2,6 +2,9 @@
 
 # -- Celery related configuration
 
+import djcelery
+djcelery.setup_loader()
+
 BROKER_URL = "amqp://guest:guest@localhost:5672//"
 CELERY_RESULT_BACKEND = "database"
 
